==> qt-creator-2.6.0-src.zip: qt-creator-2.6.0-src/src/plugins/macros/savedialog.cpp <==
/**************************************************************************
**
** Copyright (c) 2012 Nicolas Arnaud-Cormos
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "savedialog.h"
#include "ui_savedialog.h"

#include <QLineEdit>
#include <QCheckBox>
#include <QRegExpValidator>

using namespace Macros::Internal;

SaveDialog::SaveDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::SaveDialog)
{
    ui->setupUi(this);
    ui->name->setValidator(new QRegExpValidator(QRegExp("\\w*"), this));
}

SaveDialog::~SaveDialog()
{
    delete ui;
}

QString SaveDialog::name() const
{
    return ui->name->text();
}

QString SaveDialog::description() const
{
    return ui->description->text();
}

==> qt-creator-2.7.2-src.zip: qt-creator-2.7.2-src/src/plugins/macros/savedialog.cpp <==
/**************************************************************************
**
** Copyright (c) 2013 Nicolas Arnaud-Cormos
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "savedialog.h"
#include "ui_savedialog.h"

#include <QLineEdit>
#include <QCheckBox>
#include <QRegExpValidator>

using namespace Macros::Internal;

SaveDialog::SaveDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::SaveDialog)
{
    ui->setupUi(this);
    ui->name->setValidator(new QRegExpValidator(QRegExp(QLatin1String("\\w*")), this));
}

SaveDialog::~SaveDialog()
{
    delete ui;
}

QString SaveDialog::name() const
{
    return ui->name->text();
}

QString SaveDialog::description() const
{
    return ui->description->text();
}
